Package: sdmvspecies
Type: Package
Title: Create Virtual Species for Species Distribution Modelling
Version: 0.3.2
Date: 2015-12-27
Authors@R: c(
             person(given="Xiaoquan", family="Kong", email="u1mail2me@gmail.com", role=c("aut", "cre", "cph")),
             person(given="Renyan", family="Duan", role=c("ths")),
             person(given="Minyi", family="Huang", role=c("ths"))
             )
Author: Xiaoquan Kong [aut, cre, cph],
    Renyan Duan [ths],
    Minyi Huang [ths]
Maintainer: Xiaoquan Kong <u1mail2me@gmail.com>
Description: A software package help user to create virtual species for species distribution modelling. It includes
    several methods to help user to create virtual species distribution map.
    Those maps can be used for Species Distribution Modelling (SDM) study. SDM use
    environmental data for sites of occurrence of a species to predict all the sites
    where the environmental conditions are suitable for the species to persist, and
    may be expected to occur.
License: AGPL-3
Encoding: UTF-8
Imports: stats, raster, psych, parallel
Suggests: ggplot2, testthat, roxygen2
RoxygenNote: 5.0.1
URL: http://www.sdmserialsoftware.org/sdmvspecies/
BugReports: https://github.com/howl-anderson/sdmvspecies/issues
NeedsCompilation: no
Packaged: 2015-12-30 12:00:26 UTC; howl
Repository: CRAN
Date/Publication: 2015-12-30 17:00:31
Built: R 4.3.3; ; 2025-01-24 17:27:54 UTC; unix
