# Generated by roxygen2: do not edit by hand

export(artificialBellResponse)
export(autoPCA)
export(configStack)
export(nicheSynthese)
export(pickMean)
export(pickMedian)
export(rescale)
importFrom(parallel,mclapply)
importFrom(psych,principal)
importFrom(raster,"values<-")
importFrom(raster,cellStats)
importFrom(raster,getValues)
importFrom(raster,setValues)
importFrom(raster,stack)
importFrom(raster,stackApply)
importFrom(raster,values)
importFrom(stats,dnorm)
importFrom(stats,quantile)
importFrom(stats,runif)
